package org.firstinspires.ftc.teamcode.subsystem;

import static org.firstinspires.ftc.teamcode.configs.RobotConstants.armEngage;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.armPark;

import com.qualcomm.robotcore.hardware.HardwareMap;
import com.qualcomm.robotcore.hardware.ServoImplEx;

import org.firstinspires.ftc.teamcode.util.action.Actions;
import org.firstinspires.ftc.teamcode.util.action.RunAction;

public class ArmSubsystem {

    public enum ArmState {
        PARK, ENGAGE
    }

    public ServoImplEx arm;
    public ArmState state;
    public RunAction engageArm, parkArm;

    public ArmSubsystem(HardwareMap hardwareMap, ArmState armState) {
        arm = hardwareMap.get(ServoImplEx.class, "arm-servo");
        arm.resetDeviceConfigurationForOpMode();

        this.state = armState;

        parkArm = new RunAction(this::parkArm);
        engageArm = new RunAction(this::engageArm);
    }

    public void setState(ArmState armState) {
        if (armState == ArmState.ENGAGE) {
            arm.setPosition(armEngage);
            this.state = ArmState.ENGAGE;
        } else if (armState == ArmState.PARK) {
            arm.setPosition(armPark);
            this.state = ArmState.PARK;
        }
    }

    public void engageArm() {
        setState(ArmState.ENGAGE);
    }

    public void parkArm() {
        setState(ArmState.PARK);
    }

    public void switchState() {
        if (state == ArmState.ENGAGE) {
            setState(ArmState.PARK);
        } else if (state == ArmState.PARK) {
            setState(ArmState.ENGAGE);
        }
    }

    public ArmState getState() {
        return this.state;
    }

    public void init() {
        Actions.runBlocking(parkArm);
    }

    public void start() {
        Actions.runBlocking(parkArm);
    }

}
